/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 *  Copyright © 2014 Igalia S.L.
 *
 *  This file is part of Epiphany.
 *
 *  Epiphany is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Epiphany is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

G_BEGIN_DECLS

#define EPHY_WEB_PROCESS_EXTENSION_SERVICE_NAME "org.gnome.Epiphany.WebProcessExtension"
#define EPHY_WEB_PROCESS_EXTENSION_OBJECT_PATH  "/org/gnome/Epiphany/WebProcessExtension"
#define EPHY_WEB_PROCESS_EXTENSION_INTERFACE    "org.gnome.Epiphany.WebProcessExtension"

G_END_DECLS
